GEKKO
===== 

GEKKO is a python package for optimization, specializing in dynamic optimization of differential algebraic equations (DAE) systems. GEKKO provides a user-friendly interface to the powerful APMonitor optimization suite on the back end. It is coupled with large-scale solvers for linear, quadratic, nonlinear, and mixed integer programming (LP, QP, NLP, MILP, MINLP). Modes of operation include data reconciliation, real-time optimization, dynamic simulation, and nonlinear predictive control.


